/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { Inter } from "next/font/google";
import Script from "next/script";
// eslint-disable-next-line import/default, import/no-named-as-default, import/no-named-as-default-member
import PlausibleProvider from "next-plausible";
import { Footer } from "../components/footer";
import { Navigation } from "../components/navigation";
import type { Metadata } from "next";
import type { JSX, ReactNode } from "react";
// eslint-disable-next-line import/no-unassigned-import
import "./globals.css";

// eslint-disable-next-line new-cap
const inter = Inter({ subsets: [ "latin" ] });

const metadata: Metadata = {
  description:
    // eslint-disable-next-line stylistic/max-len
    "This page tells you everything you could ever want to know about Naomi and her consulting firm nhcarrigan.",
  openGraph: {
    images: "https://cdn.nhcarrigan.com/background.png",
  },
  title:   "Naomi's Portfolio",
  twitter: {
    card:   "summary_large_image",
    images: "https://cdn.nhcarrigan.com/background.png",
    site:   "@naomi_lgbt",
  },
};

/**
 * The top-level wrapper for the React application.
 * Handles mounting the shadow DOM.
 * @param opts - The rendering options.
 * @param opts.children  - The children elements to render.
 * @returns A JSX element.
 */
const RootLayout = ({
  children,
}: Readonly<{
  children: ReactNode;
}>): JSX.Element => {
  return (
    <html lang="en">
      <PlausibleProvider
        customDomain="https://analytics.nhcarrigan.com"
        domain="nhcarrigan.com"
        trackFileDownloads={true}
        trackOutboundLinks={true}
      >
        <link
          href="https://cdn.nhcarrigan.com/logo.png"
          rel="icon"
          sizes="any"
        />
        <body className={inter.className}>
          <header>
            <Navigation />
          </header>
          {children}
          <video
            autoPlay={true}
            className="fixed top-0 left-0 w-full h-full object-cover opacity-25"
            loop={true}
            muted={true}
            playsInline={true}
            src="https://cdn.nhcarrigan.com/overlay.webm"
            style={{ pointerEvents: "none" }}
          />
          <footer>
            <Footer />
          </footer>
        </body>
        <Script
          async={true}
          defer={true}
          id="hs-script-loader"
          src="//js.hs-scripts.com/47086586.js"
          type="text/javascript"
        ></Script>
      </PlausibleProvider>
    </html>
  );
};

export { metadata };
export default RootLayout;
