/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import type { JSX } from "react";

interface IssueProperties {
  labels: Array<string>;
  number: number;
  title:  string;
  url:    string;
  body:   string;
}

/**
 * Renders the view for a Codeberg issue.
 * @param properties - The issue to render.
 * @returns A JSX element.
 */
export const Issue = (properties: IssueProperties): JSX.Element => {
  const { labels, number, title, url, body } = properties;
  return (
    <div className="p-6 mb-2 bg-[--foreground] text-[--background]
        border border-gray-200 rounded-lg shadow">
      <h2 className="mb-2 text-2xl font-bold tracking-tight">{`#${number.toString()} ${title}`}</h2>
      {labels.map((label) => {
        return (
          <span
            className="inline-flex items-center bg-pink-100
              text-pink-800 text-xsfont-medium px-2.5 py-0.5
              rounded-full dark:bg-pink-900 dark:text-pink-300"
            key={label}
          >
            {label}
          </span>
        );
      })}
      <p className="mb-3 font-normal text-gray-700 dark:text-gray-400">
        {body}
      </p>
      <a
        className="inline-flex items-center px-3 py-2 text-sm
          font-medium text-center text-[--foreground] bg-[--background]
          rounded-lg focus:ring-4 focus:outline-none focus:ring-blue-300
          dark:focus:ring-blue-800"
        href={url}
        rel="noopener noreferrer"
        target="_blank"
      >
        {`View Issue`}
        <svg
          aria-hidden="true"
          className="rtl:rotate-180 w-3.5 h-3.5 ms-2"
          fill="none"
          viewBox="0 0 14 10"
          xmlns="http://www.w3.org/2000/svg"
        >
          <path
            d="M1 5h12m0 0L9 1m4 4L9 9"
            stroke="currentColor"
            strokeLinecap="round"
            strokeLinejoin="round"
            strokeWidth="2"
          />
        </svg>
      </a>
    </div>
  );
};
